Summary
-------
WYSIWYG js editor with ckeditor


If don't want to use ckeditor from //cdn set following variables in
uiprops of your main cube:

  CKEDITOR_URL = data('ckeditor/ckeditor.js')
  CKEDITOR_BASEPATH = data('ckeditor/')
